@@ -53,7 +53,7 @@ def test_version_info():
 def test_version_info_python():
     out = mv.version_info()
     assert "metview_python_version" in out
-    assert isinstance(out['metview_python_version'], str)
+    assert isinstance(out["metview_python_version"], str)
 
 
 def test_describe():
@@ -454,6 +454,12 @@ def test_fieldset_single_index():
     assert mv.grib_get_long(grib4, "level") == 500
 
 
+def test_fieldset_positive_index_too_high():
+    grib = mv.read(os.path.join(PATH, "t_for_xs.grib"))
+    with pytest.raises(IndexError):
+        grib_m1 = grib[177]
+
+
 def test_fieldset_negative_index_1():
     grib = mv.read(os.path.join(PATH, "t_for_xs.grib"))
     grib_m1 = grib[-1]  # last element
@@ -816,6 +822,34 @@ def test_fieldset_create_from_list_of_fieldsets_5():
         gl = mv.Fieldset(path=os.path.join(PATH, "test.grib"), fields=list_of_fields)
 
 
+def test_fieldset_merge_1():
+    grib = mv.read(os.path.join(PATH, "t_for_xs.grib"))
+    g3 = mv.merge(grib[1], grib[0])
+    assert g3.count() == 2
+    assert g3.grib_get_long("level") == [850, 1000]
+
+
+def test_fieldset_merge_2():
+    grib = mv.read(os.path.join(PATH, "t_for_xs.grib"))
+    g3 = mv.merge(grib[1], grib[0], grib[4])
+    assert g3.count() == 3
+    assert g3.grib_get_long("level") == [850, 1000, 400]
+
+
+def test_fieldset_merge_3():
+    grib = mv.read(os.path.join(PATH, "t_for_xs.grib"))
+    g3 = mv.merge(grib[2])
+    assert g3.count() == 1
+    assert g3.grib_get_long("level") == 700
+
+
+def test_fieldset_merge_4():
+    grib = mv.read(os.path.join(PATH, "t_for_xs.grib"))
+    g3 = mv.merge(grib[:3])
+    assert g3.count() == 3
+    assert g3.grib_get_long("level") == [1000, 850, 700]
+
+
 def test_fieldset_pickling():
     pickled_fname = file_in_testdir("pickled_fieldset.p")
     g = mv.Fieldset(path=os.path.join(PATH, "tuv_pl.grib"))
@@ -1522,6 +1556,12 @@ def test_plot_2_pages():
     os.remove(output_name_from_magics)
 
 
+def test_animate_exception():
+    # this should fail because we are not in a Jupyter environment
+    with pytest.raises(EnvironmentError):
+        mv.plot(animate=True)
+
+
 def test_macro_error():
     with pytest.raises(Exception):
         TEST_FIELDSET[125]
@@ -1666,7 +1706,7 @@ def test_set_vector_float32_from_numpy_array():
 
 
 def test_set_vector_10_bool_from_numpy_array():
-    r = np.array([1, 0, 0, 1, 1, 0, 1], dtype=np.bool)
+    r = np.array([1, 0, 0, 1, 1, 0, 1], dtype=bool)
     assert mv.type(r) == "vector"
     assert mv.dtype(r) == "float32"
     assert mv.count(r) == 7
@@ -1674,7 +1714,7 @@ def test_set_vector_10_bool_from_numpy_array():
 
 
 def test_set_vector_TF_bool_from_numpy_array():
-    r = np.array([True, False, False, True, True, False, True], dtype=np.bool)
+    r = np.array([True, False, False, True, True, False, True], dtype=bool)
     assert mv.type(r) == "vector"
     assert mv.dtype(r) == "float32"
     assert mv.count(r) == 7
@@ -1682,7 +1722,7 @@ def test_set_vector_TF_bool_from_numpy_array():
 
 
 def test_set_vector_from_int_numpy_array():
-    r = np.array([5, 8, 7, 1, 2900], dtype=np.int)
+    r = np.array([5, 8, 7, 1, 2900], dtype=int)
     assert mv.type(r) == "vector"
     assert mv.dtype(r) == "float64"
     assert mv.count(r) == 5
@@ -1834,6 +1874,14 @@ def test_read_filter_to_dataset():
     assert "t" not in x_keys  # only 'u' should be there
 
 
+def test_kwargs_to_dataset():
+    t_series = mv.read(file_in_testdir("t_time_series.grib"))
+    t0 = t_series[0]
+    ds = t0.to_dataset(squeeze=False, read_keys=["experimentVersionNumber"])
+    assert "step" in ds.dims
+    assert "GRIB_experimentVersionNumber" in ds.t.attrs
+
+
 def test_table():
     # test csv with metadata
     db = mv.read_table(
@@ -2038,7 +2086,7 @@ def test_download():
 def test_download_gallery_data():
     fname = "z_for_spectra.grib"
     assert not os.path.isfile(fname)
-    g = mv.download_gallery_data(fname)
+    g = mv.gallery.load_dataset(fname)
     assert mv.type(g) == "fieldset"
     assert os.path.isfile(fname)
     os.remove(fname)
@@ -2047,4 +2095,4 @@ def test_download_gallery_data():
 def test_download_gallery_data_bad_fname():
     fname = "zzz_for_spectra.grib"
     with pytest.raises(Exception):
-        g = mv.download_gallery_data(fname)
+        g = mv.gallery.load_dataset(fname)
